| modify_edit | R Documentation |
Internal helper for 'redesign()'. Updates variable values inside quosure environments of a design object so that rerunning the design reflects new inputs.
modify_edit(design, ...)
design |
A design object created by DeclareDesign. |
... |
Named variable updates (e.g., 'N = 20', 'b = 0.5'). |
A design with updated variables.
n <- 2
b <- 1
d <- declare_model(N = n, Y = rnorm(N, b)) + declare_inquiry(Q = b)
d2 <- redesign(d, n = 3, b = 0.2)
draw_data(d2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.